# Hatter: Decorator-based framework for AMQP clients

[![Build Status](https://cloud.drone.io/api/badges/tangibleintelligence/hatter/status.svg)](https://cloud.drone.io/tangibleintelligence/hatter)
[![PyPI version](https://badge.fury.io/py/hatter.svg)](https://badge.fury.io/py/hatter)

`hatter` is a framework to easily create microservices backed by a RabbitMQ broker.

While functional, this is still in alpha phase. Documentation, tests, and some additional functionality is still to come.